#
# spec file for package delve
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define shortname dlv

Name:           delve
Version:        1.21.0
Release:        bp156.2.9
Summary:        Debugger for the Go Programming Language
License:        MIT
Group:          Development/Languages/Go
URL:            https://github.com/go-delve/delve
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.16
# your_linux_architecture_is_not_supported_by_delve (support_sentinel_linux.go)
ExcludeArch:    s390x ppc64 ppc64le %arm riscv64

%description
Delve is a debugger for the Go programming language. The goal of
the project is to provide a simple, full featured debugging tool
for Go. Delve should be easy to invoke and easy to use. Chances are
if you're using a debugger, things aren't going your way. With that
in mind, Delve should stay out of your way as much as possible.

%prep
%autosetup -a 1

%build
# Build the binary, use PIE unless on ppc64le or s390x
# Upstream reports these as unsupported platforms so meta pkg disable
go build \
   -mod=vendor \
%ifnarch ppc64 s390x
   -buildmode=pie \
%endif
   -o %{shortname} \
   ./cmd/%{shortname}
# Upstream Makefile uses these options to build static
# fails with /usr/bin/ld: cannot find -lc
# -ldflags "-extldflags -static" \

%install
# Install the binary.
install -D -m 0755 %{shortname} "%{buildroot}/%{_bindir}/%{shortname}"

%files
%doc README.md
%doc Documentation
%license LICENSE
%{_bindir}/%{shortname}

%changelog
* Tue Aug 29 2023 Dirk Müller <dmueller@suse.com>
- update summary and architecture excludes
* Wed Jun 28 2023 jkowalczyk@suse.com
- Update to version 1.21.0:
  * all: Bump to v1.21.0 (#3428)
  * proc: skip TestDebugStripped on linux/386/pie (#3427)
  * service/dap: fix typos in comments (#3426)
  * pkg/proc: improve stripped binary support with PIE (#3421)
  * proc: only print warning when gopclntab can not be read for first image (#3420)
  * service,terminal: when libraries don't have debug_info print reason (#3419)
  * pkg/terminal: regenerate starlark mappings (#3418)
  * pkg/proc: fix ebpf probe tracing backen uprobe handling (#3417)
  * pkg/proc: enable basic debug functionality for stripped ELF binaries (#3408)
  * terminal/starbind: add online help for starlark (#3388)
  * service/dap: update go-dap to latest (#3414)
  * TeamCity: fix linux/arm64 build (second attempt) (#3411)
  * terminal: expand ~ in paths passed to 'source' (#3387)
  * proc/test: reenable cgo testing on FreeBSD (#3394)
  * terminal: ask for confirmation when using 'quit -c' with breakpoints (#3398)
  * TeamCity: fix linux/arm64 build (#3403)
  * rpc2, debugger: Fix comments around goroutine grouping (#3374)
  * cmd/commands: Fix to read debug info file from the correct directory when using trace command with -e option. (#3405)
  * starbind: fix use of ptr variables in starlark  (#3386)
  * debugger: inline clearBreakpoint, createLogicalBreakpoint (#3389)
  * TeamCity: actually run linux/386 tests on linux/386 (#3392)
  * service/rpccommon: correct wrong comments (#3397)
  * docgen: fix links with trailing dots  (#3399)
  * dwarf: ignore DeclLine for function args (#3400)
  * _scripts: fix typos (#3402)
  * dwarf/op: use readMemory function (#3391)
  * starbind: Make the time module available to star scripts (#3375)
  * documentation: add a note about starlark structs (#3376)
  * debuginfod-find stderr may contain diagnostics; look at stdout only for filename (#3381)
  * dwarf,proc: fix typos in comments and error messages (#3379)
  * service: fix typos in comments, logs, tests, and vars (#3378)
  * proc: remove addrret field from Stackframe struct (#3373)
  * pkg/proc,pkg/terminal: close response body in tests (#3372)
  * cmd/dlv,service/dap: use randomized name as default output binary (#3366)
  * pkg/proc: pad variable mem in extractVarInfoFromEntry (#3365)
  * cmd/dlv: logger is not closed in connect command (#3367)
  * proc: fix runtime type handling for Go 1.21 (#3370)
  * proc,terminal: read command line of new processes (#3346)
  * trace: add timestamp to the output (#3358)
  * service/dap: refactor funcs always returning nil error (#3357)
  * dwarf/godwarf: fix alignment calculation for typedef types (#3362)
  * refactor: replace `Readdir(-1)` with `os.ReadDir` (#3361)
  * chore: don't ignore directory cmd/dlv (#3359)
  * pkg/proc: add missing response body Close in test (#3355)
  * pkg/proc: remove memlock limit for ebpf trace backend (#3353)
  * *: misc improvements to config command and substitute-path rules (#3335)
  * service/dap: use reloaded value
  * service/dap,service/debugger: refactor regexp funcs
  * proc/test: replace old func testName with T.Name
  * service: fix typos in comments (#3344)
  * Add additional information to how to filter goroutines
  * service/debugger,terminal: API and user interface for follow exec mode (#3286)
  * proc/native: support core dumping on FreeBSD (#3305)
  * debugger: do not panic if defer location can not be found (#3329)
  * proc: Simplify eBPF backend implementation (#3325)
  * proc: step breakpoints shouldn't hide normal breakpoints (#3287)
  * service/dap: fix failing test on Go 1.21 (#3312)
  * proc: disable flaky tests on windows/arm64 (#3328)
  * proc: fix match condition in TestGnuDebuglink
  * proc: fix test by adding missing assert
* Thu Apr  6 2023 jkowalczyk@suse.com
- Update to version 1.20.2:
  * proc: fix TestEvalExpression on Windows (#3313)
  * terminal: Fix printing boolean values in Starlark scripts (#3314)
  * proc: fix escapeCheck infinite recursion if something can not be (#3311)
  * proc: support multiple functions with the same name (#3297)
  * proc: fuzzing expression evaluator and variable loader (#3293)
  * proc: limit maximum time.Time we try to format (#3294)
  * Documentation: expand project layout to match usage (#3304)
  * proc: fix automatic breakpoints visibility (#3300)
  * proc,terminal: remove unused unexported functions (#3299)
  * cmd/dlv: Add flag to replay for rr onprocess pid (#3281)
  * proc: do not try to load a non-empty slice if the base address is 0 (#3295)
  * Documentation: fix typo and grammar issues (#3291)
  * dwarf/line: enable TestGrafana on Windows (#3289)
  * dwarf/op: change generated comment header (#3288)
  * proc,proc/native: adds ability to automatically debug child processes (#3165)
  * Default to stop test_windows.ps1 when there is an error (#3285)
  * dwarf/line: handle end_seq properly (#3277)
  * proc: remove unused parameter from resolveParametricType (#3276)
  * TeamCity,Documentation: use new TeamCity URL (#3275)
  * terminal/logflags: Added `SetLoggerFactory(LoggerFactory)` (#3257)
  * *: remove some code for Go 1.12 or earlier (#3271)
  * pkg/proc,service/test: refactor to strings.ReplaceAll (#3269)
  * _scripts: Update staticcheck (#3270)
  * proc/native: fix syscalls to SYS_PROCESS_VM_READV (and WRITEV) (#3273)
  * dwarf: fix broken external url to arm dwarf mapping (#3272)
  * Documentation: watch example for arbitrary address (#3268)
  * service/dap: correct typos in comments (#3264)
  * cmd/dlv: fix exit status for trace subcommand  (#3263)
  * godwarf: Allow extracting a DWARF entry's field (#3258)
  * _scripts: fix log.Printf format specifier (#3260)
  * cmd/dlv, pkg/proc: use T.TempDir in tests (#3256)
  * pkg/proc: do not check decl line for FunctionArguments (#3254)
  * terminal: use exact window size for pager (#3249)
  * proc/dwarf: Move util functions to dwarf package (#3252)
  * proc/dwarf: LEB128 encode/decode in separate pkg (#3235)
  * debugger,terminal: Allow setting and clearing breakpoints after process exit (#3246)
  * pkg/terminal: use default for Y/n empty response (#3248)
  * godwarf: Attempt to load `DW_AT_specification` if present (#3247)
  * terminal: Add config options for tab printing (#3243)
  * pkg/proc: fix stripping DYLD_INSERT_LIBRARIES on macOS (#3245)
  * cmd/dlv: match go test behavior when dlv test gets a list of .go files (#3232)
  * pkg/proc: populate pointer values (#3229)
  * pkg/terminal: fix handling list colors via config (#3240)
  * Documentation: document how to debug runtime with Delve (#3234)
  * go.mod: update github.com/google/go-dap to v0.7.0 (#3237)
  * pkg/proc: apply simplifycompositelit analysis fixes (#3236)
  * proc: Fix typos in the comments (#3231)
  * service/debugger: fix comment on EvalVariableInScope (#3225)
  * proc/native: fix FreeBSD backend (#3224)
  * TeamCity: fix windows/amd64 builds (#3223)
  * Documentation/faq: Correct commands in substitute-path section (#3222)
  * *: Change comments to match common Go standarts (#3221)
  * Update github.com/derekparker/trie dependency (#3219)
  * dwarf/frame: Remove expression constants (#3218)
  * proc: replace os.SEEK_CUR with io.SeekCurrent (#3214)
  * Documentation: add -test.run to test example (#3212)
- Packaging update source service mode to manual formerly disabled
* Tue Dec 13 2022 jkowalczyk@suse.com
- Update to version 1.20.1:
  * gdbserial: continue if tcsetpgrp fails (#3211)
* Thu Dec  8 2022 jkowalczyk@suse.com
- Update to version 1.20.0:
  * *: CHANGELOG and bump to version 1.20.0 (#3209)
  * Test windows/arm64 pipeline (#3200)
  * proc: extend macOS workaround to amd64 (#3204)
  * proc/gdbserver: set child process pgrp as foreground group (#3205)
  * *: early fixes for go1.20 (#3180)
  * Run CI tests on windows/arm64 agents (#3198)
  * cmd/dlv: Include hidden flag -c for coredumpctl support (#3195)
  * G struct offset is a pointer to an offset since go1.20 (#3196)
  * proc: prefer addresses when setting a breakpoint (#3193)
  * pkg/proc: fix arm64 linux cgo stacktrace (#3192)
  * Two fixes to type cast evaluation (#3186)
  * bininfo: Log when the file listed in .gnu_debuglink is not found (#3188)
  * service/debugger: allow setting a breakpoint with a specific ID (#3185)
  * proc/gdbserial/gdbserver: Don't pass DYLD_INSERT_LIBRARIES to debugserver (#3181)
  * proc: fix index access to already-loaded string values (#3184)
  * service/debugger: Assume current dir for exec (#3167)
  * pkg/terminal: Improve error when unable to read history file (#3169)
  * Add type to call evaluation and expression evaluation (#3172)
  * proc/native: acquire debug programs privilege on Windows (#3162)
  * pkg: fix a few function names on comments
  * service/dap: fix nil ptr deref when current addr is not in a func (#3157)
  * proc: disable TestCGONext on darwin/amd64 (#3160)
  * proc: remove import "C" for linux/386 backend (#3159)
  * proc,terminal: allow setting suspended breakpoints (#3154)
  * Documentation: add homebrew installation instructions back again
  * cmd/dlv: disable TestTraceMultipleGoroutines on FreeBSD (#3144)
  * proc: allow type casts between compatible types (#3149)
  * proc: remove old method to resolve the type of an interface to a DIE (#3150)
  * proc,service/debugger: track how breakpoints were originally set (#3148)
  * proc,service: change FindLocation to work with multiple targets (#3103)
  * service/dap: show full value when evaluating log messages (#3141)
  * proc,_scripts/rtype.go: add rtype annotations for g.atomicstatus (#3143)
  * proc: fix openSeparateDebugInfo backwards compatibility path (#3145)
  * proc: fix cast to empty interface type (#3146)
  * proc/native: fix support_sentinel_darwin.go name (#3147)
  * Add support for windows/arm64 (#3063)
  * service/debugger: merge attachErrorMessage, verifyBinaryFormat (#3142)
  * terminal: do not use WaitSince as unix time (#3139)
  * proc: fix hang caused by g.atomicstatus has change to atomic.Uint32 (#3129)
  * go.mod,proc: upgrade golang.org/x/sys/unix (#3134)
  * proc: reduntant type conversion (#3131)
  * terminal: remove leftover GOPATH references (#3117)
  * Add Debugger to UIs list in EditorIntegration (#3127)
  * Documentation: reverse step, next and stepout (#3119)
* Tue Aug 23 2022 jkowalczyk@suse.com
- Update to version 1.9.1:
  * v1.9.1 (#3116)
  * proc: make sure logical breakpoints map exists (#3115)
  * go.mod: update starlark dependency (#3112)
  * terminal: send large output to pager (#3060)
  * *: switch to int64 for goroutine IDs (#3110)
  * proc: use stdlib to compute CRC for gnu_debuglink section (#3105)
  * _scripts: fix CI on go1.19/linux/386 (#3100)
  * service/dap: Add support for empty string in substitutePath (#3088)
  * proc: fuse evalToplevelTypeCast and evalTypeCast (#3057)
  * _scripts: fix command to download Go version (#3099)
  * service/debugger: refactor state/collectBreakpointInfo for TargetGroup (#3064)
  * proc: do not panic reading bad G struct (#3098)
  * TeamCity,goversion: bump test matrix (#3092)
  * pkg/dwarf/line: Fix parsing file table for DWARFv5 (#3090)
  * :* Improve trace subcommand output (#3091)
  * Documentation: fix documentation of examinemem (#3087)
  * fix StepInstruction on 1 byte instruction with a software breackpoint (#3084)
  * pkg/proc/internal/ebpf: Fix handling of entry / return (#3081)
  * service/dap: fix indexing bug for maps (#3068)
  * pkg/proc/internal/ebpf: Fix size of ebpf type for fn_addr (#3080)
  * proc/native: refactor windows framework (#3079)
  * terminal/command: 'goroutines' command add new flags '-exec command' (#3044)
  * proc: support gnu_debuglink section (#3073)
  * pkg/locspec: support exact match in SubstitutePath (#3075)
  * proc/internal/ebpf: drop dependency on cgo (#3072)
  * cmd/dlv,proc: misc improvements to trace subcommand (#3069)
  * dwarf/op,proc: output register name when printing location exprs (#3052)
  * service/dap: limit disassembly range (#3045)
  * proc,service/debugger: introduce TargetGroup abstraction (#3030)
  * terminal: add ability to show disassembly instead of source (#3047)
  * terminal/command: add -per-g-hitcount option to condition command (#3055)
  * _scripts: un-pin mingw version (#3046)
* Mon Aug 22 2022 Dirk Müller <dmueller@suse.com>
- update list of excluded archs with those that raise
  your_operating_system_and_architecture_combination_is_not_supported_by_delve exception
* Wed Jul  6 2022 jkowalczyk@suse.com
- Update to version 1.9.0:
  * *: Bump version to 1.9.0 (#3054)
  * vendor: update version of go/packages to 0.1.11 (#3053)
  * proc: fix arm64SwitchStack for go1.19 (#3038)
  * dwarf/frame: discard indirect flag reading personality func in eh_frame (#3032)
  * proc/native: fix Ctrl-C handling on non-headless instances on windows (#3039)
  * proc: map access with string literal key should always succeed (#3036)
  * testcase: remove accidental debug binary (#3035)
  * *: run go1.19 'go fmt' on everything and fix problems (#3031)
  * proc/gdbserver: ignore spurious stop packet from debugserver (#3021)
  * service/test,proc: move variable evaluation test to pkg/proc (#3024)
  * proc: fix prettyprint for register components with large values (#3022)
  * go.mod: use pseudo verion for github.com/go-delve/liner (#3026)
  * pkg/proc: fix and improve freebsd register handling (#3019)
  * proc/native: fix Windows build (#3023)
  * proc,service: represent logical breakpoints explicitly (#2946)
  * dap: add MultiClientCloseServerMock and fix test shutdown leak (#3011)
  * pkg/terminal: Add auto-complete for local variables (#3004)
  * proc: fix fatal throw breakpoint on go1.19 (#3009)
  * dap: remote attach must not use terminateDebuggee in single-client launch mode (#2995)
  * proc/gdbserver: fix function call injection on rr (#3007)
  * proc: fix RFLAGS corruption after call injection on amd64 (#3002)
  * proc: fixes concerning call injection on freebsd and rr (#3000)
  * Documentation: document substitute-path more (#2998)
  * proc/core: return true for calls to Recorded (#2979)
  * proc: support function call injection on arm64 (#2996)
  * Documentation: add DAP launch/attach configuration matrix (#2991)
  * _scripts/test_linux.sh,_scripts/test_windows.ps1: always return exit code 0 when testing on tip (#2997)
  * proc: fix autogenerated helper skip on linux/386 PIE builds (#2975)
  * _scripts: always return exit code 0 when testing on tip (#2980)
  * proc: unlock OS thread on exit from handlePtraceFuncs (#2972)
  * service/debugger: close executable file (#2976)
  * proc: add support for setting additional registers on freebsd/amd64 (#2981)
  * service/debugger: make TestDebugger_LaunchWithTTY pass on FreeBSD (#2982)
* Sun Jun 26 2022 Berthold Gunreben <azouhr@opensuse.org>
- s390x is not in list of supported CPUs. Disable building for s390x.
* Wed May 18 2022 jkowalczyk@suse.com
- Initial package version 1.8.3:
  * Documentation: expand DAP launch/attach configurations section (#2977)
  * Documentation: Fix example block in cli README (#2974)
  * _scripts/make: do not exit if git SHA ID can not be retrieved (#2973)
  * proc: skip autogenerated functions correctly (#2959)
  * dlv dap: pass disable-aslr to backend (#2965)
  * gobuild: drop support for building on Go < 1.10 (#2960)
  * Documentation/api/dap/README: add dlv dap usage link (#2957)
  * CHANGELOG.md: fix date typos (#2956)
  * proc/gdbserial: shut down debuggee when failing to debug (#2953)
  * debugger: clarify no debug info errors (#2954)
  * dlv_test: fix TestChildProcessExitWhenNoDebugInfo to actually test strip binary (#2949)
  * proc: allow low index == len in reslice (#2951)
  * proc,service: pretty print time.Time variables (#2865)
  * *: fix some typos
  * Prefer locspec to linespec (#2941)
  * service/dap: support terminateDebuggee option for attach only (#2940)
  * proc: move resume notify and manual stop handling to Target (#2921)
  * proc/native/linux: replace uses of unix.Iovec for target addresses (#2922)
  * Documentation/api/dap/README: add release version links (#2923)
  * service-*: conform to godoc comments (#2916)
